@@ -10,8 +10,8 @@
  *     Olof Sivertsson <olsi0767@student.uu.se>
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-19 11:41:29 +0100 (Thu, 19 Mar 2015) $ by $Author: tack $
+ *     $Revision: 14461 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -109,7 +109,7 @@ public:
 
   /// Actual model
   BIBD(const BIBDOptions& o)
-    : opt(o), _p(*this,opt.v*opt.b,0,1) {
+    : Script(o), opt(o), _p(*this,opt.v*opt.b,0,1) {
     Matrix<BoolVarArray> p(_p,opt.b,opt.v);
 
     // r ones per row
@@ -129,11 +129,6 @@ public:
         linear(*this, row, IRT_EQ, opt.lambda);
       }
 
-    // IntVarArray ints(*this, opt.v*opt.b, 0, 1);
-    // for (int i = 0 ; i < opt.v*opt.b ; i++)
-    //   rel(*this, ints[i] == _p[i]);
-    // Matrix<IntVarArray> intm(ints, opt.b, opt.v);
-
     if (opt.symmetry() == SYMMETRY_LDSB) {
       Symmetries s;
       s << rows_interchange(p);
