@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -245,7 +245,8 @@ protected:
 public:
   /// Initial model
   CarSequencing(const CarOptions& opt)
-    : problem(opt.size()),
+    : Script(opt),
+      problem(opt.size()),
       ncars(problems[problem][0]), 
       noptions(problems[problem][1]), 
       nclasses(problems[problem][2]),
