@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2012
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -361,7 +361,8 @@ public:
 
   /// Actual model
   ColoredMatrix(const ColoredMatrixOptions& opt0)
-    : opt(opt0), height(opt.height()), width(opt.width()), colors(opt.colors()),
+    : IntMinimizeScript(opt0), 
+      opt(opt0), height(opt.height()), width(opt.width()), colors(opt.colors()),
       x(*this, height*width, 1, colors),
       max_color(*this, 1, colors)
   {
