@@ -7,8 +7,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:30:12 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14448 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -69,7 +69,7 @@ using namespace Gecode;
  *
  * \ingroup Example
  */
-class DescartesFolium : public Script {
+class DescartesFolium : public FloatMaximizeScript {
 protected:
   /// The numbers
   FloatVarArray f;
@@ -77,8 +77,8 @@ protected:
   double step;
 public:
   /// Actual model
-  DescartesFolium(const Options&) 
-    : f(*this,3,-20,20), step(0.1) {
+  DescartesFolium(const Options& opt) 
+    : FloatMaximizeScript(opt), f(*this,3,-20,20) {
     // Post equation
     FloatVar p = f[0];
     FloatVar x = f[1];
@@ -92,17 +92,16 @@ public:
   }
   /// Constructor for cloning \a p
   DescartesFolium(bool share, DescartesFolium& p) 
-    : Script(share,p), step(p.step) {
+    : FloatMaximizeScript(share,p) {
     f.update(*this,share,p.f);
   }
   /// Copy during cloning
   virtual Space* copy(bool share) { 
     return new DescartesFolium(share,*this); 
   }
-  /// Add constraint to current model to get next solution (not too close)
-  virtual void constrain(const Space& _b) {
-    const DescartesFolium& b = static_cast<const DescartesFolium&>(_b);
-    rel(*this, f[0] >= (b.f[0].max()+step));
+  /// Cost function
+  virtual FloatVar cost(void) const {
+    return f[0];
   }
   /// Print solution coordinates
   virtual void print(std::ostream& os) const {
@@ -117,9 +116,10 @@ public:
  */
 int main(int argc, char* argv[]) {
   Options opt("DescartesFolium");
-  opt.parse(argc,argv);
   opt.solutions(0);
-  Script::run<DescartesFolium,BAB,Options>(opt);
+  opt.step(0.1);
+  opt.parse(argc,argv);
+  FloatMaximizeScript::run<DescartesFolium,BAB,Options>(opt);
   return 0;
 }
 
