@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -129,7 +129,8 @@ protected:
 public:
   /// Actual model
   EFPA(const EFPAOptions& opt)
-    : v(opt.v()),
+    : Script(opt), 
+      v(opt.v()),
       q(opt.q()),
       l(opt.l()),
       d(opt.d()),
