@@ -9,8 +9,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2013-02-25 21:43:24 +0100 (Mon, 25 Feb 2013) $ by $Author: schulte $
- *     $Revision: 13406 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -139,6 +139,15 @@ public:
     else 
       return me_failed(x[c.pos].nq(home, c.val)) ? ES_FAILED : ES_OK;
   }
+  /// Print explanation
+  virtual void print(const Space&, const Gecode::Choice& _c, 
+                     unsigned int a,
+                     std::ostream& o) const {
+    const Choice& c = static_cast<const Choice&>(_c);
+    o << "x[" << c.pos << "] "
+      << ((a == 0) ? "=" : "!=")
+      << " " << c.val;
+  }
   /// Copy brancher
   virtual Actor* copy(Space& home, bool share) {
     return new (home) Warnsdorff(home, share, *this);
@@ -199,7 +208,7 @@ public:
   }
   /// Constructor
   Knights(const SizeOptions& opt)
-    : n(opt.size()), succ(*this,n*n,0,n*n-1) {
+    : Script(opt), n(opt.size()), succ(*this,n*n,0,n*n-1) {
     switch (opt.branching()) {
     case BRANCH_NAIVE:
       branch(*this, succ, INT_VAR_NONE(), INT_VAL_MIN());
