@@ -9,8 +9,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -74,7 +74,7 @@ public:
   };
   /// The actual model
   MagicSequence(const SizeOptions& opt)
-    : n(opt.size()), s(*this,n,0,n-1) {
+    : Script(opt), n(opt.size()), s(*this,n,0,n-1) {
     switch (opt.propagation()) {
     case PROP_COUNT:
       for (int i=n; i--; )
