@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2012-09-07 11:29:57 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
- *     $Revision: 13061 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -97,7 +97,7 @@ private:
 public:
   /// Actual model
   MineSweeper(const SizeOptions& opt)
-    : spec(specs[opt.size()]),
+    : Script(opt), spec(specs[opt.size()]),
       size(spec_size(spec)),
       b(*this,size*size,0,1) {
     Matrix<BoolVarArray> m(b, size, size);
