@@ -9,8 +9,8 @@
  *     Mikael Lagerkvist, 2005
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -200,7 +200,8 @@ public:
   };
   /// Actual model
   PerfectSquare(const SizeOptions& opt)
-    : x(*this,specs[opt.size()][0],0,specs[opt.size()][1]-1),
+    : Script(opt), 
+      x(*this,specs[opt.size()][0],0,specs[opt.size()][1]-1),
       y(*this,specs[opt.size()][0],0,specs[opt.size()][1]-1) {
 
     const int* s = specs[opt.size()];
