@@ -7,8 +7,8 @@
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -69,7 +69,7 @@ public:
   };
   /// The actual problem
   Queens(const SizeOptions& opt)
-    : q(*this,opt.size(),0,opt.size()-1) {
+    : Script(opt), q(*this,opt.size(),0,opt.size()-1) {
     const int n = q.size();
     switch (opt.propagation()) {
     case PROP_BINARY:
