@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -119,7 +119,7 @@ private:
 public:
   /// The actual problem
   Radiotherapy(const SizeOptions& opt)
-  : rd(rds[opt.size()]) {
+  : IntMinimizeScript(opt), rd(rds[opt.size()]) {
 
     // Initialize variables
     beamtime = IntVar(*this, rd.btMin, rd.intsSum);
