@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -67,7 +67,7 @@ public:
 
   /// Actual model
   Steiner(const SizeOptions& opt)
-    : n(opt.size()), noOfTriples((n*(n-1))/6),
+    : Script(opt), n(opt.size()), noOfTriples((n*(n-1))/6),
       triples(*this, noOfTriples, IntSet::empty, 1, n, 3, 3) {
 
     for (int i=0; i<noOfTriples; i++) {
