@@ -11,8 +11,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2013-07-08 14:22:40 +0200 (Mon, 08 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13820 $
+ *     $Date: 2015-03-17 16:09:39 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14447 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -84,7 +84,9 @@ public:
   };
 
   /// Constructor
-  Sudoku(const SizeOptions& opt) : n(example_size(examples[opt.size()])) {}
+  Sudoku(const SizeOptions& opt) 
+    : Script(opt),
+      n(example_size(examples[opt.size()])) {}
 
   /// Constructor for cloning \a s
   Sudoku(bool share, Sudoku& s) : Script(share,s), n(s.n) {}
