@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2013-10-15 00:43:28 +0200 (Tue, 15 Oct 2013) $ by $Author: tack $
- *     $Revision: 14024 $
+ *     $Date: 2015-03-17 16:09:10 +0100 (Tue, 17 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14446 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -365,6 +365,8 @@ namespace Gecode {
       _icl("-icl","integer consistency level",ICL_DEF),
       _branching("-branching","branching variants"),
       _decay("-decay","decay factor",1.0),
+      _seed("-seed","random number generator seed",1U),
+      _step("-step","step distance for float optimization",0.0),
       
       _search("-search","search engine variants"),
       _solutions("-solutions","number of solutions (0 = all)",1),
@@ -411,7 +413,7 @@ namespace Gecode {
     _restart.add(RM_GEOMETRIC,"geometric");
     
     add(_model); add(_symmetry); add(_propagation); add(_icl); 
-    add(_branching); add(_decay);
+    add(_branching); add(_decay); add(_seed); add(_step);
     add(_search); add(_solutions); add(_threads); add(_c_d); add(_a_d);
     add(_node); add(_fail); add(_time); add(_interrupt);
     add(_restart); add(_r_base); add(_r_scale); 
