@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2013-09-27 09:30:50 +0200 (Fri, 27 Sep 2013) $ by $Author: tack $
- *     $Revision: 14015 $
+ *     $Date: 2015-03-17 11:20:12 +0100 (Tue, 17 Mar 2015) $ by $Author: tack $
+ *     $Revision: 14444 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -60,13 +60,13 @@ namespace Gecode { namespace FlatZinc {
   }
 
   void
-  Registry::post(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+  Registry::post(FlatZincSpace& s, const ConExpr& ce) {
     std::map<std::string,poster>::iterator i = r.find(ce.id);
     if (i == r.end()) {
       throw FlatZinc::Error("Registry",
         std::string("Constraint ")+ce.id+" not found");
     }
-    i->second(s, ce, ann);
+    i->second(s, ce, ce.ann);
   }
 
   void
@@ -107,10 +107,12 @@ namespace Gecode { namespace FlatZinc {
     void p_distinct(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs va = s.arg2intvarargs(ce[0]);
       IntConLevel icl = s.ann2icl(ann);
+      unshare(s, va);
       distinct(s, va, icl == ICL_DEF ? ICL_BND : icl);
     }
     void p_distinctOffset(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs va = s.arg2intvarargs(ce[1]);
+      unshare(s, va);
       AST::Array* offs = ce.args->a[0]->getArray();
       IntArgs oa(offs->a.size());
       for (int i=offs->a.size(); i--; ) {
@@ -921,7 +923,11 @@ namespace Gecode { namespace FlatZinc {
       }
       l << load;
       IntArgs sizes = s.arg2intargs(ce[2]);
-      binpacking(s, l, bin, sizes, s.ann2icl(ann));
+
+      IntVarArgs allvars = l + bin;
+      unshare(s, allvars);
+      binpacking(s, allvars.slice(0,1,l.size()), allvars.slice(l.size(),1,bin.size()),
+                 sizes, s.ann2icl(ann));
     }
 
     void p_global_cardinality(FlatZincSpace& s, const ConExpr& ce,
@@ -953,6 +959,7 @@ namespace Gecode { namespace FlatZinc {
                  allvars.slice(iv0.size(),1,iv1.size()),
                  cover, s.ann2icl(ann));
       } else {
+        unshare(s, iv0);
         count(s, iv0, iv1, cover, s.ann2icl(ann));
       }
     }
@@ -962,6 +969,7 @@ namespace Gecode { namespace FlatZinc {
       IntVarArgs iv0 = s.arg2intvarargs(ce[0]);
       IntArgs cover = s.arg2intargs(ce[1]);
       IntVarArgs iv1 = s.arg2intvarargs(ce[2]);
+      unshare(s, iv0);
       count(s, iv0, iv1, cover, s.ann2icl(ann));
     }
 
@@ -989,7 +997,7 @@ namespace Gecode { namespace FlatZinc {
           y << IntSet(0,x.size());
         }
       }
-      
+      unshare(s, x);
       count(s, x, y, cover, s.ann2icl(ann));
     }
 
@@ -1004,7 +1012,7 @@ namespace Gecode { namespace FlatZinc {
       IntSetArgs y(cover.size());
       for (int i=cover.size(); i--;)
         y[i] = IntSet(lbound[i],ubound[i]);
-
+      unshare(s, x);
       count(s, x, y, cover, s.ann2icl(ann));
     }
 
@@ -1018,6 +1026,16 @@ namespace Gecode { namespace FlatZinc {
       max(s, iv, s.arg2IntVar(ce[0]), s.ann2icl(ann));
     }
 
+    void p_minimum_arg(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      IntVarArgs iv = s.arg2intvarargs(ce[0]);
+      argmin(s, iv, s.arg2IntVar(ce[1]), true, s.ann2icl(ann));
+    }
+
+    void p_maximum_arg(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      IntVarArgs iv = s.arg2intvarargs(ce[0]);
+      argmax(s, iv, s.arg2IntVar(ce[1]), true, s.ann2icl(ann));
+    }
+
     void p_regular(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs iv = s.arg2intvarargs(ce[0]);
       int q = ce[1]->getInt();
@@ -1065,6 +1083,7 @@ namespace Gecode { namespace FlatZinc {
         
       DFA dfa(q0,t,f);
       free(f);
+      unshare(s, iv);
       extensional(s, iv, dfa, s.ann2icl(ann));
     }
 
@@ -1088,8 +1107,10 @@ namespace Gecode { namespace FlatZinc {
     void
     p_inverse_offsets(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       IntVarArgs x = s.arg2intvarargs(ce[0]);
+      unshare(s, x);
       int xoff = ce[1]->getInt();
       IntVarArgs y = s.arg2intvarargs(ce[2]);
+      unshare(s, y);
       int yoff = ce[3]->getInt();
       channel(s, x, xoff, y, yoff, s.ann2icl(ann));
     }
@@ -1153,6 +1174,17 @@ namespace Gecode { namespace FlatZinc {
       extensional(s,x,ts,EPK_DEF,s.ann2icl(ann));
     }
 
+    void p_cumulative_opt(FlatZincSpace& s, const ConExpr& ce,
+                      AST::Node* ann) {
+      IntVarArgs start = s.arg2intvarargs(ce[0]);
+      IntArgs duration = s.arg2intargs(ce[1]);
+      IntArgs height = s.arg2intargs(ce[2]);
+      BoolVarArgs opt = s.arg2boolvarargs(ce[3]);
+      int bound = ce[4]->getInt();
+      unshare(s,start);
+      cumulative(s,bound,start,duration,height,opt,s.ann2icl(ann));
+    }
+
     void p_cumulatives(FlatZincSpace& s, const ConExpr& ce,
                       AST::Node* ann) {
       IntVarArgs start = s.arg2intvarargs(ce[0]);
@@ -1161,12 +1193,24 @@ namespace Gecode { namespace FlatZinc {
       int n = start.size();
       IntVar bound = s.arg2IntVar(ce[3]);
 
-      int minHeight = INT_MAX; int minHeight2 = INT_MAX;
-      for (int i=n; i--;)
-        if (height[i].min() < minHeight)
+      if (n==0)
+        return;
+
+      if (n == 1) {
+        rel(s, height[0] <= bound);
+        return;
+      }
+      
+      int minHeight = std::min(height[0].min(),height[1].min());
+      int minHeight2 = std::max(height[0].min(),height[1].min());
+      for (int i=2; i<n; i++) {
+        if (height[i].min() < minHeight) {
+          minHeight2 = minHeight;
           minHeight = height[i].min();
-        else if (height[i].min() < minHeight2)
+        } else if (height[i].min() < minHeight2) {
           minHeight2 = height[i].min();
+        }
+      }
       bool disjunctive =
        (minHeight > bound.max()/2) ||
        (minHeight2 > bound.max()/2 && minHeight+minHeight2>bound.max());
@@ -1177,11 +1221,13 @@ namespace Gecode { namespace FlatZinc {
           IntArgs durationI(n);
           for (int i=n; i--;)
             durationI[i] = duration[i].val();
+          unshare(s,start);
           unary(s,start,durationI);
         } else {
           IntVarArgs end(n);
           for (int i=n; i--;)
             end[i] = expr(s,start[i]+duration[i]);
+          unshare(s,start);
           unary(s,start,duration,end);
         }
       } else if (height.assigned()) {
@@ -1235,6 +1281,7 @@ namespace Gecode { namespace FlatZinc {
       int q = ce[2]->getInt();
       int l = ce[3]->getInt();
       int u = ce[4]->getInt();
+      unshare(s, x);
       sequence(s, x, S, q, l, u, s.ann2icl(ann));
     }
 
@@ -1246,12 +1293,14 @@ namespace Gecode { namespace FlatZinc {
       int l = ce[3]->getInt();
       int u = ce[4]->getInt();
       IntSet S(val, val);
+      unshare(s, x);
       sequence(s, x, S, q, l, u, s.ann2icl(ann));
     }
 
     void p_schedule_unary(FlatZincSpace& s, const ConExpr& ce, AST::Node*) {
       IntVarArgs x = s.arg2intvarargs(ce[0]);
       IntArgs p = s.arg2intargs(ce[1]);
+      unshare(s,x);
       unary(s, x, p);
     }
 
@@ -1260,12 +1309,14 @@ namespace Gecode { namespace FlatZinc {
       IntVarArgs x = s.arg2intvarargs(ce[0]);
       IntArgs p = s.arg2intargs(ce[1]);
       BoolVarArgs m = s.arg2boolvarargs(ce[2]);
+      unshare(s,x);
       unary(s, x, p, m);
     }
 
     void p_circuit(FlatZincSpace& s, const ConExpr& ce, AST::Node *ann) {
       int off = ce[0]->getInt();
       IntVarArgs xv = s.arg2intvarargs(ce[1]);
+      unshare(s,xv);
       circuit(s,off,xv,s.ann2icl(ann));
     }
     void p_circuit_cost_array(FlatZincSpace& s, const ConExpr& ce,
@@ -1274,12 +1325,14 @@ namespace Gecode { namespace FlatZinc {
       IntVarArgs xv = s.arg2intvarargs(ce[1]);
       IntVarArgs yv = s.arg2intvarargs(ce[2]);
       IntVar z = s.arg2IntVar(ce[3]);
+      unshare(s,xv);
       circuit(s,c,xv,yv,z,s.ann2icl(ann));
     }
     void p_circuit_cost(FlatZincSpace& s, const ConExpr& ce, AST::Node *ann) {
       IntArgs c = s.arg2intargs(ce[0]);
       IntVarArgs xv = s.arg2intvarargs(ce[1]);
       IntVar z = s.arg2IntVar(ce[2]);
+      unshare(s,xv);
       circuit(s,c,xv,z,s.ann2icl(ann));
     }
 
@@ -1296,6 +1349,27 @@ namespace Gecode { namespace FlatZinc {
         for (int i=h.size(); i--;)
           ih[i] = h[i].val();
         nooverlap(s,x0,iw,y0,ih,s.ann2icl(ann));
+        
+        int miny = y0[0].min();
+        int maxy = y0[0].max();
+        int maxdy = ih[0];
+        for (int i=1; i<y0.size(); i++) {
+          miny = std::min(miny,y0[i].min());
+          maxy = std::max(maxy,y0[i].max());
+          maxdy = std::max(maxdy,ih[i]);
+        }
+        int minx = x0[0].min();
+        int maxx = x0[0].max();
+        int maxdx = iw[0];
+        for (int i=1; i<x0.size(); i++) {
+          minx = std::min(minx,x0[i].min());
+          maxx = std::max(maxx,x0[i].max());
+          maxdx = std::max(maxdx,iw[i]);
+        }
+        if (miny > Int::Limits::min && maxy < Int::Limits::max) {
+          cumulative(s,maxdy+maxy-miny,x0,iw,ih);
+          cumulative(s,maxdx+maxx-minx,y0,ih,iw);
+        }
       } else {
         IntVarArgs x1(x0.size()), y1(y0.size());
         for (int i=x0.size(); i--; )
@@ -1328,8 +1402,10 @@ namespace Gecode { namespace FlatZinc {
       IntSet v = s.arg2intset(ce[2]);
       if (ce[0]->isIntVar()) {
         IntVar n = s.arg2IntVar(ce[0]);
+        unshare(s, x);
         count(s,x,v,IRT_EQ,n,s.ann2icl(ann));
       } else {
+        unshare(s, x);
         count(s,x,v,IRT_EQ,ce[0]->getInt(),s.ann2icl(ann));
       }
     }
@@ -1476,8 +1552,11 @@ namespace Gecode { namespace FlatZinc {
           &p_global_cardinality_low_up);
         registry().add("global_cardinality_low_up_closed", 
           &p_global_cardinality_low_up_closed);
-        registry().add("minimum_int", &p_minimum);
-        registry().add("maximum_int", &p_maximum);
+        registry().add("array_int_minimum", &p_minimum);
+        registry().add("array_int_maximum", &p_maximum);
+        registry().add("gecode_minimum_arg_int", &p_minimum_arg);
+        registry().add("gecode_maximum_arg_int", &p_maximum_arg);
+        registry().add("array_int_maximum", &p_maximum);
         registry().add("regular", &p_regular);
         registry().add("sort", &p_sort);
         registry().add("inverse_offsets", &p_inverse_offsets);
@@ -1513,6 +1592,7 @@ namespace Gecode { namespace FlatZinc {
         
         registry().add("gecode_schedule_unary", &p_schedule_unary);
         registry().add("gecode_schedule_unary_optional", &p_schedule_unary_optional);
+        registry().add("gecode_schedule_cumulative_optional", &p_cumulative_opt);
 
         registry().add("gecode_circuit", &p_circuit);
         registry().add("gecode_circuit_cost_array", &p_circuit_cost_array);
@@ -1690,6 +1770,7 @@ namespace Gecode { namespace FlatZinc {
       assert(idx >= 0);
       rel(s, x || IntSet(Set::Limits::min,idx-1));
       BoolVarArgs y = s.arg2boolvarargs(ce[1],idx);
+      unshare(s, y);
       channel(s, y, x);
     }
 
@@ -1910,10 +1991,17 @@ namespace Gecode { namespace FlatZinc {
     void p_float_lin_le(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
       p_float_lin_cmp(s,FRT_LQ,ce,ann);
     }
+    void p_float_lin_lt(FlatZincSpace& s, const ConExpr& ce, AST::Node* ann) {
+      p_float_lin_cmp(s,FRT_LE,ce,ann);
+    }
     void p_float_lin_le_reif(FlatZincSpace& s, const ConExpr& ce,
                              AST::Node* ann) {
       p_float_lin_cmp_reif(s,FRT_LQ,ce,ann);
     }
+    void p_float_lin_lt_reif(FlatZincSpace& s, const ConExpr& ce,
+                             AST::Node* ann) {
+      p_float_lin_cmp_reif(s,FRT_LE,ce,ann);
+    }
 
     void p_float_times(FlatZincSpace& s, const ConExpr& ce, AST::Node*) {
       FloatVar x = s.arg2FloatVar(ce[0]);
@@ -2065,7 +2153,9 @@ namespace Gecode { namespace FlatZinc {
         registry().add("float_lin_eq",&p_float_lin_eq);
         registry().add("float_lin_eq_reif",&p_float_lin_eq_reif);
         registry().add("float_lin_le",&p_float_lin_le);
+        registry().add("float_lin_lt",&p_float_lin_lt);
         registry().add("float_lin_le_reif",&p_float_lin_le_reif);
+        registry().add("float_lin_lt_reif",&p_float_lin_lt_reif);
         
 #ifdef GECODE_HAS_MPFR
         registry().add("float_acos",&p_float_acos);
