@@ -11,8 +11,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2013-10-11 09:00:31 +0200 (Fri, 11 Oct 2013) $ by $Author: tack $
- *     $Revision: 14022 $
+ *     $Date: 2015-01-16 14:10:48 +0100 (Fri, 16 Jan 2015) $ by $Author: schulte $
+ *     $Revision: 14362 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -43,120 +43,6 @@
 
 namespace Gecode { namespace Int { namespace Element {
 
-  /// VarArg type for integer views
-  template<>
-  class ViewToVarArg<IntView> {
-  public:
-    typedef IntVarArgs argtype;
-  };
-  /// VarArg type for Boolean views
-  template<>
-  class ViewToVarArg<BoolView> {
-  public:
-    typedef BoolVarArgs argtype;
-  };
-
-  /**
-   * \brief Class for pair of index and view
-   *
-   */
-  template<class View>
-  class IdxView {
-  public:
-    int idx; View view;
-
-    static IdxView* allocate(Space&, int);
-  };
-
-  template<class View>
-  forceinline IdxView<View>*
-  IdxView<View>::allocate(Space& home, int n) {
-    return home.alloc<IdxView<View> >(n);
-  }
-
-  template<class View>
-  IdxViewArray<View>::IdxViewArray(void) : xs(NULL), n(0) {}
-
-  template<class View>
-  IdxViewArray<View>::IdxViewArray(const IdxViewArray<View>& a) {
-    n = a.n; xs = a.xs;
-  }
-
-  template<class View>
-  IdxViewArray<View>::IdxViewArray(Space& home,
-    const typename ViewToVarArg<View>::argtype& xa) : xs(NULL) {
-    n = xa.size();
-    if (n>0) {
-      xs = IdxView<View>::allocate(home, n);
-      for (int i = n; i--; ) {
-        xs[i].idx = i; xs[i].view = xa[i];
-      }
-    }
-  }
-
-  template<class View>
-  IdxViewArray<View>::IdxViewArray(Space& home, int n0) : xs(NULL) {
-    n = n0;
-    if (n>0) {
-      xs = IdxView<View>::allocate(home, n);
-    }
-  }
-
-  template<class View>
-  forceinline int
-  IdxViewArray<View>::size(void) const {
-    return n;
-  }
-
-  template<class View>
-  forceinline void
-  IdxViewArray<View>::size(int n0) {
-    n = n0;
-  }
-
-  template<class View>
-  forceinline IdxView<View>&
-  IdxViewArray<View>::operator [](int i) {
-    assert((i >= 0) && (i < size()));
-    return xs[i];
-  }
-
-  template<class View>
-  forceinline const IdxView<View>&
-  IdxViewArray<View>::operator [](int i) const {
-    assert((i >= 0) && (i < size()));
-    return xs[i];
-  }
-
-  template<class View>
-  void
-  IdxViewArray<View>::subscribe(Space& home, Propagator& p, PropCond pc,
-                                bool process) {
-    for (int i = n; i--; )
-      xs[i].view.subscribe(home,p,pc,process);
-  }
-
-  template<class View>
-  void
-  IdxViewArray<View>::cancel(Space& home, Propagator& p, PropCond pc) {
-    for (int i = n; i--; )
-      xs[i].view.cancel(home,p,pc);
-  }
-
-  template<class View>
-  void
-  IdxViewArray<View>::update(Space& home, bool share, IdxViewArray<View>& a) {
-    n = a.size();
-    if (n>0) {
-      xs = IdxView<View>::allocate(home,n);
-      for (int i=n; i--; ) {
-        xs[i].idx = a[i].idx;
-        xs[i].view.update(home,share,a[i].view);
-      }
-    }
-  }
-
-
   /**
    * \brief Class for bounds-equality test
    *
