@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10365 $
+ *     $Date: 2012-09-07 17:31:22 +0200 (Fri, 07 Sep 2012) $ by $Author: schulte $
+ *     $Revision: 13068 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -67,6 +67,13 @@ namespace Gecode {
     using namespace Int;
     if (!t.finalized())
       throw NotYetFinalized("Int::extensional");
+    if (t.tuples()==0) {
+      if (x.size()!=0) {
+        home.fail();
+      }
+      return;
+    }
+    
     if (t.arity() != x.size())
       throw ArgumentSizeMismatch("Int::extensional");
     if (home.failed()) return;
@@ -96,6 +103,14 @@ namespace Gecode {
     using namespace Int;
     if (!t.finalized())
       throw NotYetFinalized("Int::extensional");
+
+    if (t.tuples()==0) {
+      if (x.size()!=0) {
+        home.fail();
+      }
+      return;
+    }
+
     if (t.arity() != x.size())
       throw ArgumentSizeMismatch("Int::extensional");
     if (home.failed()) return;
