@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2013-10-30 16:01:30 +0100 (Wed, 30 Oct 2013) $ by $Author: schulte $
- *     $Revision: 14038 $
+ *     $Date: 2015-01-05 07:32:41 +0100 (Mon, 05 Jan 2015) $ by $Author: tack $
+ *     $Revision: 14336 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -79,9 +79,10 @@ namespace Gecode {
    *
    */
   void
-  NoGoods::post(Space&) {
+  NoGoods::post(Space&) const {
   }
 
+  NoGoods NoGoods::eng;
 
   /*
    * Brancher
@@ -644,13 +645,18 @@ namespace Gecode {
   Space::constrain(const Space&) {
   }
 
-  void
-  Space::master(unsigned long int, const Space*, NoGoods& ng) {
-    ng.post(*this);
+  bool
+  Space::master(const CRI& cri) {
+    if (cri.last() != NULL)
+      constrain(*cri.last());
+    cri.nogoods().post(*this);
+    // Perform a restart even if a solution has been found
+    return true;
   }
 
-  void
-  Space::slave(unsigned long int, const Space*) {
+  bool
+  Space::slave(const CRI&) {
+    return true;
   }
 
   void
