@@ -7,8 +7,8 @@
  *     Christian Schulte, 2010
  *
  *  Last modified:
- *     $Date: 2013-03-11 14:47:11 +0100 (Mon, 11 Mar 2013) $ by $Author: schulte $
- *     $Revision: 13490 $
+ *     $Date: 2013-08-19 14:00:39 +0200 (Mon, 19 Aug 2013) $ by $Author: schulte $
+ *     $Revision: 13982 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -882,6 +882,28 @@ namespace Gecode {
   sum(const IntArgs& a, const BoolVarArgs& x) {
     return LinIntExpr(a,x);
   }
+  LinIntExpr 
+  sum(const Slice<IntArgs>& slice) {
+    const Slice<IntArgs>::ArgsType & args = slice;
+    return sum(args);
+  }
+  LinIntExpr 
+  sum(const Matrix<IntArgs>& matrix) {
+    const Matrix<IntArgs>::ArgsType & args = matrix.get_array();
+    return sum(args);
+  }
+  LinIntExpr
+  sum(const IntArgs& args) {
+    int i, sum = 0;
+    const int size = args.size();
+
+    for (i = 0 ; i < size ; ++i)    
+    {
+      sum += args[i];
+    }
+
+    return LinIntExpr(sum);
+  }
 
 
   IntVar
