@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2013-07-11 12:30:18 +0200 (Thu, 11 Jul 2013) $ by $Author: schulte $
- *     $Revision: 13840 $
+ *     $Date: 2015-03-11 15:59:09 +0100 (Wed, 11 Mar 2015) $ by $Author: schulte $
+ *     $Revision: 14435 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,6 +39,24 @@
 
 namespace Gecode { namespace Search {
 
+   /*
+    * Creation functions for stop objects
+    *
+    */
+  Stop*
+  Stop::node(unsigned long int l) {
+    return new NodeStop(l);
+  }
+  Stop*
+  Stop::fail(unsigned long int l) {
+    return new FailStop(l);
+  }
+  Stop*
+  Stop::time(unsigned long int l) {
+    return new TimeStop(l);
+  }
+
+
   /*
    * Stopping for node limit
    *
@@ -69,27 +87,6 @@ namespace Gecode { namespace Search {
   }
 
 
-  /*
-   * Stopping for meta search engines
-   *
-   */
-
-  bool 
-  MetaStop::stop(const Statistics& s, const Options& o) {
-    // Stop if the fail stop object for the engine says so
-    if (e_stop->stop(s,o)) {
-      e_stopped = true;
-      m_stat.restart++;
-      return true;
-    }
-    // Stop if the stop object for the meta engine says so
-    if ((m_stop != NULL) && m_stop->stop(m_stat+s,o)) {
-      e_stopped = false;
-      return true;
-    }
-    return false;
-  }
-
 }}
 
 // STATISTICS: search-other
