@@ -7,8 +7,8 @@
  *     Christian Schulte, 2012
  *
  *  Last modified:
- *     $Date: 2013-03-07 02:18:29 +0100 (Thu, 07 Mar 2013) $ by $Author: mears $
- *     $Revision: 13455 $
+ *     $Date: 2013-05-02 17:10:16 +0200 (Thu, 02 May 2013) $ by $Author: schulte $
+ *     $Revision: 13603 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -40,7 +40,8 @@
 namespace Gecode {
   BrancherHandle
   branch(Home home, const SetVarArgs& x,
-         SetVarBranch vars, SetValBranch vals, SetBranchFilter bf) {
+         SetVarBranch vars, SetValBranch vals, 
+         SetBranchFilter bf, SetVarValPrint vvp) {
     using namespace Set;
     if (home.failed()) return BrancherHandle();
     vars.expand(home,x);
@@ -49,12 +50,13 @@ namespace Gecode {
       Branch::viewsel(home,vars) 
     };
     return ViewValBrancher<SetView,1,int,2>::post
-      (home,xv,vs,Branch::valselcommit(home,vals),bf);
+      (home,xv,vs,Branch::valselcommit(home,vals),bf,vvp);
   }
 
   BrancherHandle
   branch(Home home, const SetVarArgs& x,
-         TieBreak<SetVarBranch> vars, SetValBranch vals, SetBranchFilter bf) {
+         TieBreak<SetVarBranch> vars, SetValBranch vals, 
+         SetBranchFilter bf, SetVarValPrint vvp) {
     using namespace Set;
     if (home.failed()) return BrancherHandle();
     vars.a.expand(home,x);
@@ -71,7 +73,7 @@ namespace Gecode {
       vars.d = SET_VAR_NONE();
     vars.d.expand(home,x);
     if (vars.b.select() == SetVarBranch::SEL_NONE) {
-      return branch(home,x,vars.a,vals,bf);
+      return branch(home,x,vars.a,vals,bf,vvp);
     } else {
       ViewArray<SetView> xv(home,x);
       ValSelCommitBase<SetView,int>* vsc = Branch::valselcommit(home,vals); 
@@ -79,32 +81,32 @@ namespace Gecode {
         ViewSel<SetView>* vs[2] = { 
           Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b)
         };
-        return ViewValBrancher<SetView,2,int,2>::post(home,xv,vs,vsc,bf);
+        return ViewValBrancher<SetView,2,int,2>::post(home,xv,vs,vsc,bf,vvp);
       } else if (vars.d.select() == SetVarBranch::SEL_NONE) {
         ViewSel<SetView>* vs[3] = { 
           Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
           Branch::viewsel(home,vars.c)
         };
-        return ViewValBrancher<SetView,3,int,2>::post(home,xv,vs,vsc,bf);
+        return ViewValBrancher<SetView,3,int,2>::post(home,xv,vs,vsc,bf,vvp);
       } else {
         ViewSel<SetView>* vs[4] = { 
           Branch::viewsel(home,vars.a),Branch::viewsel(home,vars.b),
           Branch::viewsel(home,vars.c),Branch::viewsel(home,vars.d)
         };
-        return ViewValBrancher<SetView,4,int,2>::post(home,xv,vs,vsc,bf);
+        return ViewValBrancher<SetView,4,int,2>::post(home,xv,vs,vsc,bf,vvp);
       }
     }
   }
 
   BrancherHandle
-  branch(Home home, SetVar x, SetValBranch vals) {
+  branch(Home home, SetVar x, SetValBranch vals, SetVarValPrint vvp) {
     SetVarArgs xv(1); xv[0]=x;
-    return branch(home, xv, SET_VAR_NONE(), vals);
+    return branch(home, xv, SET_VAR_NONE(), vals, NULL, vvp);
   }
   
   BrancherHandle
   assign(Home home, const SetVarArgs& x, SetAssign sa,
-         SetBranchFilter bf) {
+         SetBranchFilter bf, SetVarValPrint vvp) {
     using namespace Set;
     if (home.failed()) return BrancherHandle();
     ViewArray<SetView> xv(home,x);
@@ -112,13 +114,13 @@ namespace Gecode {
       new (home) ViewSelNone<SetView>(home,SET_VAR_NONE())
     };
     return ViewValBrancher<SetView,1,int,1>::post
-      (home,xv,vs,Branch::valselcommit(home,sa),bf);
+      (home,xv,vs,Branch::valselcommit(home,sa),bf,vvp);
   }
 
   BrancherHandle
-  assign(Home home, SetVar x, SetAssign sa) {
+  assign(Home home, SetVar x, SetAssign sa, SetVarValPrint vvp) {
     SetVarArgs xv(1); xv[0]=x;
-    return assign(home, xv, sa);
+    return assign(home, xv, sa, NULL, vvp);
   }
   
 }
