@@ -11,8 +11,8 @@
  *     Vincent Barichard, 2012
  *
  *  Last modified:
- *     $Date: 2013-03-05 14:40:46 +0100 (Tue, 05 Mar 2013) $ by $Author: schulte $
- *     $Revision: 13435 $
+ *     $Date: 2015-01-16 06:05:16 +0100 (Fri, 16 Jan 2015) $ by $Author: tack $
+ *     $Revision: 14357 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,6 +42,7 @@
 #include "test/float.hh"
 
 #include <algorithm>
+#include <iomanip>
 
 namespace Test { namespace Float {
 
@@ -202,9 +203,9 @@ namespace Test { namespace Float {
   bool 
   TestSpace::matchAssignment(const Assignment& a) const {
     for (int i=x.size(); i--; )
-      if ((x[i].min() != a[i].min()) || (x[i].max() != a[i].max()))
+      if ((x[i].min() < a[i].min()) && (x[i].max() > a[i].max()))
         return false;
-      return true;
+    return true;
   }
   
   void 
@@ -358,6 +359,8 @@ namespace Test { namespace Float {
     case 0:
       if (a[i].max() < x[i].max()) {
         Gecode::FloatNum v=randFValDown(a[i].max(),x[i].max());
+        if (v==x[i].max())
+          v = a[i].max();
         assert((v >= a[i].max()) && (v <= x[i].max()));
         rel(i, Gecode::FRT_LQ, v);
       }
@@ -365,6 +368,8 @@ namespace Test { namespace Float {
     case 1:
       if (a[i].min() > x[i].min()) {
         Gecode::FloatNum v=randFValUp(x[i].min(),a[i].min());
+        if (v==x[i].min())
+          v = a[i].min();
         assert((v <= a[i].min()) && (v >= x[i].min()));
         rel(i, Gecode::FRT_GQ, v);
       }
